@@ -52,6 +52,7 @@ public:
    * @param entry The entry to show
    */
   void showEntry(Data::EntryPtr entry);
+  void showText(const QString& text);
 
   /**
    * Clear the widget and set Entry pointer to NULL
@@ -67,6 +68,9 @@ public:
   void setXSLTOptions(const StyleOptions& options);
   void setUseGradientImages(bool b) { m_useGradientImages = b; }
 
+signals:
+  void signalAction(const KURL& url);
+
 public slots:
   /**
    * Helper function to refresh view.
@@ -89,6 +93,7 @@ private:
   Data::EntryPtr m_entry;
   XSLTHandler* m_handler;
   QString m_xsltFile;
+  QString m_textToShow;
 
   // to run any clicked processes
   QGuardedPtr<KRun> m_run;
