@@ -55,7 +55,7 @@ public:
   virtual Data::EntryPtr fetchEntry(uint uid);
   virtual Type type() const { return IMDB; }
   virtual bool canFetch(int type) const;
-  virtual void readConfigHook(KConfig* config, const QString& group);
+  virtual void readConfigHook(const KConfigGroup& config);
 
   virtual void updateEntry(Data::EntryPtr entry);
 
@@ -66,7 +66,7 @@ public:
   class ConfigWidget : public Fetch::ConfigWidget {
   public:
     ConfigWidget(QWidget* parent_, const IMDBFetcher* fetcher = 0);
-    virtual void saveConfig(KConfig*);
+    virtual void saveConfig(KConfigGroup& config);
     virtual QString preferredName() const;
 
   private:
