@@ -30,6 +30,10 @@
 #include "translators/gcfilmsimporter.h"
 #include "translators/filelistingimporter.h"
 #include "translators/amcimporter.h"
+#include "translators/griffithimporter.h"
+#include "translators/pdfimporter.h"
+#include "translators/referencerimporter.h"
+#include "translators/deliciousimporter.h"
 
 #include <klocale.h>
 #include <kstandarddirs.h>
@@ -46,10 +50,10 @@ const unsigned Tellico::Import::Importer::s_stepSize = 20;
 
 using Tellico::ImportDialog;
 
-ImportDialog::ImportDialog(Import::Format format_, const KURL& url_, QWidget* parent_, const char* name_)
+ImportDialog::ImportDialog(Import::Format format_, const KURL::List& urls_, QWidget* parent_, const char* name_)
     : KDialogBase(parent_, name_, true /*modal*/, i18n("Import Options"), Ok|Cancel),
       m_coll(0),
-      m_importer(importer(format_, url_)) {
+      m_importer(importer(format_, urls_)) {
   QWidget* widget = new QWidget(this);
   QVBoxLayout* topLayout = new QVBoxLayout(widget, 0, spacingHint());
 
@@ -87,6 +91,10 @@ ImportDialog::ImportDialog(Import::Format format_, const KURL& url_, QWidget* pa
   topLayout->addStretch();
   setMainWidget(widget);
 
+  KGuiItem ok = KStdGuiItem::ok();
+  ok.setText(i18n("&Import"));
+  setButtonOK(ok);
+
   // want to grab default button action, too
   // since the importer might do something with widgets, don't just call it, do it after layout is done
   QTimer::singleShot(0, this, SLOT(slotUpdateAction()));
@@ -119,31 +127,39 @@ Tellico::Import::Action ImportDialog::action() const {
 }
 
 // static
-Tellico::Import::Importer* ImportDialog::importer(Import::Format format_, const KURL& url_) {
+Tellico::Import::Importer* ImportDialog::importer(Import::Format format_, const KURL::List& urls_) {
+#define CHECK_SIZE if(urls_.size() > 1) kdWarning() << "ImportDialog::importer() - only importing first URL" << endl
+  KURL firstURL = urls_.isEmpty() ? KURL() : urls_[0];
   Import::Importer* importer = 0;
   switch(format_) {
     case Import::TellicoXML:
-      importer = new Import::TellicoImporter(url_);
+      CHECK_SIZE;
+      importer = new Import::TellicoImporter(firstURL);
       break;
 
     case Import::Bibtex:
-      importer = new Import::BibtexImporter(url_);
+      CHECK_SIZE;
+      importer = new Import::BibtexImporter(urls_);
       break;
 
     case Import::Bibtexml:
-      importer = new Import::BibtexmlImporter(url_);
+      CHECK_SIZE;
+      importer = new Import::BibtexmlImporter(firstURL);
       break;
 
     case Import::CSV:
-      importer = new Import::CSVImporter(url_);
+      CHECK_SIZE;
+      importer = new Import::CSVImporter(firstURL);
       break;
 
     case Import::XSLT:
-      importer = new Import::XSLTImporter(url_);
+      CHECK_SIZE;
+      importer = new Import::XSLTImporter(firstURL);
       break;
 
     case Import::MODS:
-      importer = new Import::XSLTImporter(url_);
+      CHECK_SIZE;
+      importer = new Import::XSLTImporter(firstURL);
       {
         QString xsltFile = locate("appdata", QString::fromLatin1("mods2tellico.xsl"));
         if(!xsltFile.isEmpty()) {
@@ -157,35 +173,59 @@ Tellico::Import::Importer* ImportDialog::importer(Import::Format format_, const
       break;
 
     case Import::AudioFile:
-      importer = new Import::AudioFileImporter(url_);
+      CHECK_SIZE;
+      importer = new Import::AudioFileImporter(firstURL);
       break;
 
     case Import::Alexandria:
+      CHECK_SIZE;
       importer = new Import::AlexandriaImporter();
       break;
 
     case Import::FreeDB:
+      CHECK_SIZE;
       importer = new Import::FreeDBImporter();
       break;
 
     case Import::RIS:
-      importer = new Import::RISImporter(url_);
+      importer = new Import::RISImporter(urls_);
       break;
 
     case Import::GCfilms:
-      importer = new Import::GCfilmsImporter(url_);
+      CHECK_SIZE;
+      importer = new Import::GCfilmsImporter(firstURL);
       break;
 
     case Import::FileListing:
-      importer = new Import::FileListingImporter(url_);
+      CHECK_SIZE;
+      importer = new Import::FileListingImporter(firstURL);
       break;
 
     case Import::AMC:
-      importer = new Import::AMCImporter(url_);
+      CHECK_SIZE;
+      importer = new Import::AMCImporter(firstURL);
       break;
 
-    default:
-      myDebug() << "ImportDialog::importer() - not implemented!" << endl;
+    case Import::Griffith:
+      importer = new Import::GriffithImporter();
+      break;
+
+    case Import::PDF:
+      importer = new Import::PDFImporter(urls_);
+      break;
+
+    case Import::Referencer:
+      CHECK_SIZE;
+      importer = new Import::ReferencerImporter(firstURL);
+      break;
+
+    case Import::Delicious:
+      CHECK_SIZE;
+      importer = new Import::DeliciousImporter(firstURL);
+      break;
+
+    case Import::GRS1:
+      myDebug() << "ImportDialog::importer() - GRS1 not implemented" << endl;
       break;
   }
 #ifndef NDEBUG
@@ -194,6 +234,7 @@ Tellico::Import::Importer* ImportDialog::importer(Import::Format format_, const
   }
 #endif
   return importer;
+#undef CHECK_SIZE
 }
 
 // static
@@ -219,6 +260,7 @@ QString ImportDialog::fileFilter(Import::Format format_) {
       break;
 
     case Import::MODS:
+    case Import::Delicious:
       text = i18n("*.xml|XML Files (*.xml)") + QChar('\n');
       break;
 
@@ -235,11 +277,20 @@ QString ImportDialog::fileFilter(Import::Format format_) {
       text = i18n("*.amc|AMC Data Files (*.amc)") + QChar('\n');
       break;
 
+    case Import::PDF:
+      text = i18n("*.pdf|PDF Files (*.pdf)") + QChar('\n');
+      break;
+
+    case Import::Referencer:
+      text = i18n("*.reflib|Referencer Files (*.reflib)") + QChar('\n');
+      break;
+
     case Import::AudioFile:
     case Import::Alexandria:
     case Import::FreeDB:
     case Import::FileListing:
-    default:
+    case Import::GRS1:
+    case Import::Griffith:
       break;
   }
 
@@ -254,6 +305,7 @@ Tellico::Import::Target ImportDialog::importTarget(Import::Format format_) {
     case Import::AudioFile:
     case Import::FileListing:
       return Import::Dir;
+    case Import::Griffith:
     case Import::Alexandria:
     case Import::FreeDB:
       return Import::None;
@@ -263,15 +315,22 @@ Tellico::Import::Target ImportDialog::importTarget(Import::Format format_) {
 }
 
 Tellico::Import::FormatMap ImportDialog::formatMap() {
+  // at one point, these were translated, but after some thought
+  // I decided they were likely to be the same in any language
+  // transliteration is unlikely
   Import::FormatMap map;
   map[Import::TellicoXML] = QString::fromLatin1("Tellico");
-  map[Import::Bibtex]     = i18n("Bibtex");
-  map[Import::Bibtexml]   = i18n("Bibtexml");
-//  map[Import::CSV]        = i18n("CSV");
-  map[Import::MODS]       = i18n("MODS");
-  map[Import::RIS]        = i18n("RIS");
-  map[Import::GCfilms]    = i18n("GCstar");
-  map[Import::AMC]        = i18n("AMC");
+  map[Import::Bibtex]     = QString::fromLatin1("Bibtex");
+  map[Import::Bibtexml]   = QString::fromLatin1("Bibtexml");
+//  map[Import::CSV]        = QString::fromLatin1("CSV");
+  map[Import::MODS]       = QString::fromLatin1("MODS");
+  map[Import::RIS]        = QString::fromLatin1("RIS");
+  map[Import::GCfilms]    = QString::fromLatin1("GCstar");
+  map[Import::AMC]        = QString::fromLatin1("AMC");
+  map[Import::Griffith]   = QString::fromLatin1("Griffith");
+  map[Import::PDF]        = QString::fromLatin1("PDF");
+  map[Import::Referencer] = QString::fromLatin1("Referencer");
+  map[Import::Delicious ] = QString::fromLatin1("Delicious Library");
   return map;
 }
 
@@ -286,6 +345,15 @@ QString ImportDialog::startDir(Import::Format format_) {
   return QString::fromLatin1(":import");
 }
 
+void ImportDialog::slotOk() {
+  // some importers, like the CSV importer, can validate their settings
+  if(!m_importer || m_importer->validImport()) {
+    KDialogBase::slotOk();
+  } else {
+    myLog() << "ImportDialog::slotOk() - not a valid import" << endl;
+  }
+}
+
 void ImportDialog::slotUpdateAction() {
   // distasteful hack
   // selectedId() is new in QT 3.2
